@@ -1,5 +1,5 @@
-/* Copyright 2017 - 2024 R. Thomas
- * Copyright 2017 - 2024 Quarkslab
+/* Copyright 2017 - 2025 R. Thomas
+ * Copyright 2017 - 2025 Quarkslab
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -26,6 +26,7 @@
 #include "spdlog/fmt/ranges.h"
 
 #include "LIEF/span.hpp"
+#include "LIEF/optional.hpp"
 #include "LIEF/errors.hpp"
 #include "LIEF/iterators.hpp"
 
@@ -201,24 +202,65 @@ inline std::string hex_str(uint8_t c) {
 }
 
 std::string hex_dump(const std::vector<uint8_t>& data,
-                              const std::string& sep = ":");
+                     const std::string& sep = ":");
 
 std::string hex_dump(span<const uint8_t> data,
                      const std::string& sep = ":");
 
-std::string dump(const uint8_t* buffer, size_t size,
-                 const std::string& title = "", const std::string& prefix = "", size_t limit = 0);
+std::string indent(const std::string& input, size_t level);
 
-inline std::string dump(span<const uint8_t> data,
-                 const std::string& title = "", const std::string& prefix = "", size_t limit = 0) {
-  return dump(data.data(), data.size(), title, prefix, limit);
+inline bool is_digit(char c) {
+  return '0' <= c && c <= '9';
 }
 
-inline std::string dump(const std::vector<uint8_t>& data,
-                 const std::string& title = "", const std::string& prefix = "", size_t limit = 0) {
-  return dump(data.data(), data.size(), title, prefix, limit);
+inline bool is_digit(const std::string& str) {
+  return std::all_of(str.begin(), str.end(), (bool(*)(char))&is_digit);
 }
 
+inline bool is_digit(const char* str) {
+  while (*str != 0) {
+    if (!is_digit(*str)) {
+      return false;
+    }
+    ++str;
+  }
+  return true;
+}
+
+std::string ts_to_str(uint64_t timestamp);
+
+template <size_t N>
+inline std::string uuid_to_str_impl(uint8_t (&uuid)[N]) {
+  std::vector<std::string> hexstr;
+  std::transform(std::begin(uuid), std::end(uuid), std::back_inserter(hexstr),
+    [] (uint8_t x) { return fmt::format("{:02x}", x); }
+  );
+  return fmt::to_string(fmt::join(hexstr, ":"));
+}
+
+template <size_t N>
+inline std::string uuid_to_str_impl(const std::array<uint8_t, N>& uuid) {
+  std::vector<std::string> hexstr;
+  std::transform(std::begin(uuid), std::end(uuid), std::back_inserter(hexstr),
+    [] (uint8_t x) { return fmt::format("{:02x}", x); }
+  );
+  return fmt::to_string(fmt::join(hexstr, ":"));
+}
+
+inline bool endswith(const std::string& str, const std::string& suffix) {
+  if (suffix.size() > str.size()) {
+    return false;
+  }
+  return std::equal(suffix.rbegin(), suffix.rend(), str.rbegin());
+}
+
+inline optional<std::string> libname(const std::string& path, char sep = '/') {
+  size_t pos = path.rfind(sep);
+  if (pos == std::string::npos) {
+    return nullopt();
+  }
+  return path.substr(pos + 1);
+}
 
 }
 
