@@ -9,7 +9,7 @@ from pathlib import Path
 from subprocess import Popen
 
 import lief
-from utils import get_sample, has_recent_glibc, is_linux, is_x86_64
+from utils import get_sample, has_recent_glibc, is_linux, is_x86_64, has_private_samples
 
 is_updated_linux = is_linux() and is_x86_64() and has_recent_glibc()
 
@@ -290,3 +290,9 @@ def test_misc():
     raw_bytes = bytes(int(c, 16) for c in hexdigits)
 
     assert isinstance(lief.ELF.Segment.from_raw(raw_bytes), lief.ELF.Segment)
+
+
+@pytest.mark.skipif(not has_private_samples(), reason="needs private samples")
+def test_issue_1241():
+    elf = lief.ELF.parse(get_sample("private/ELF/issue_1241.bin"))
+    assert len(elf.gnu_hash.bloom_filters) == 16384
